# This file was auto-generated by Fern from our API Definition.

import typing
import urllib.parse
from json.decoder import JSONDecodeError

import pydantic

from ...core.api_error import ApiError
from ...core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ...core.jsonable_encoder import jsonable_encoder
from ...types.model_version_compile_prompt_response import ModelVersionCompilePromptResponse
from ...types.model_version_read import ModelVersionRead

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class ModelVersionsClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def retrieve(self, id: str) -> ModelVersionRead:
        """

        <strong style="background-color:#ffc107; color:white; padding:4px; border-radius:4px">Unstable</strong>

        Used to retrieve a model version given its ID.

        Parameters:
            - id: str. A UUID string identifying this model version.
        """
        _response = self._client_wrapper.httpx_client.request(
            "GET",
            urllib.parse.urljoin(f"{self._client_wrapper.get_environment().default}/", f"v1/model-versions/{id}"),
            headers=self._client_wrapper.get_headers(),
            timeout=None,
        )
        if 200 <= _response.status_code < 300:
            return pydantic.parse_obj_as(ModelVersionRead, _response.json())  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def model_version_compile_prompt(
        self, id: str, *, input_values: typing.Dict[str, typing.Any]
    ) -> ModelVersionCompilePromptResponse:
        """
        <strong style="background-color:#ffc107; color:white; padding:4px; border-radius:4px">Unstable</strong>

        Compiles the prompt backing the model version using the provided input values.

        Parameters:
            - id: str. A UUID string identifying this model version.

            - input_values: typing.Dict[str, typing.Any]. Key/value pairs for each variable found within the model version's prompt template.
        """
        _response = self._client_wrapper.httpx_client.request(
            "POST",
            urllib.parse.urljoin(
                f"{self._client_wrapper.get_environment().default}/", f"v1/model-versions/{id}/compile-prompt"
            ),
            json=jsonable_encoder({"input_values": input_values}),
            headers=self._client_wrapper.get_headers(),
            timeout=None,
        )
        if 200 <= _response.status_code < 300:
            return pydantic.parse_obj_as(ModelVersionCompilePromptResponse, _response.json())  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)


class AsyncModelVersionsClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def retrieve(self, id: str) -> ModelVersionRead:
        """

        <strong style="background-color:#ffc107; color:white; padding:4px; border-radius:4px">Unstable</strong>

        Used to retrieve a model version given its ID.

        Parameters:
            - id: str. A UUID string identifying this model version.
        """
        _response = await self._client_wrapper.httpx_client.request(
            "GET",
            urllib.parse.urljoin(f"{self._client_wrapper.get_environment().default}/", f"v1/model-versions/{id}"),
            headers=self._client_wrapper.get_headers(),
            timeout=None,
        )
        if 200 <= _response.status_code < 300:
            return pydantic.parse_obj_as(ModelVersionRead, _response.json())  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def model_version_compile_prompt(
        self, id: str, *, input_values: typing.Dict[str, typing.Any]
    ) -> ModelVersionCompilePromptResponse:
        """
        <strong style="background-color:#ffc107; color:white; padding:4px; border-radius:4px">Unstable</strong>

        Compiles the prompt backing the model version using the provided input values.

        Parameters:
            - id: str. A UUID string identifying this model version.

            - input_values: typing.Dict[str, typing.Any]. Key/value pairs for each variable found within the model version's prompt template.
        """
        _response = await self._client_wrapper.httpx_client.request(
            "POST",
            urllib.parse.urljoin(
                f"{self._client_wrapper.get_environment().default}/", f"v1/model-versions/{id}/compile-prompt"
            ),
            json=jsonable_encoder({"input_values": input_values}),
            headers=self._client_wrapper.get_headers(),
            timeout=None,
        )
        if 200 <= _response.status_code < 300:
            return pydantic.parse_obj_as(ModelVersionCompilePromptResponse, _response.json())  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class ContentType(str, enum.Enum):
    """
    * `STRING` - STRING
    * `JSON` - JSON
    """

    STRING = "STRING"
    JSON = "JSON"

    def visit(self, string: typing.Callable[[], T_Result], json: typing.Callable[[], T_Result]) -> T_Result:
        if self is ContentType.STRING:
            return string()
        if self is ContentType.JSON:
            return json()



# This file was auto-generated by Fern from our API Definition.

from . import deployments, document_indexes, documents, model_versions, registered_prompts, sandboxes, test_suites

__all__ = [
    "deployments",
    "document_indexes",
    "documents",
    "model_versions",
    "registered_prompts",
    "sandboxes",
    "test_suites",
]



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic

from ..core.datetime_utils import serialize_datetime
from .evaluation_params import EvaluationParams


class TestSuiteTestCase(pydantic.BaseModel):
    test_case_id: typing.Optional[str] = pydantic.Field(
        description="The id of the test case to update. If none is provided, an id will be generated and a new test case will be appended."
    )
    label: typing.Optional[str] = pydantic.Field(description="A human-friendly label for the test case.")
    input_values: typing.Dict[str, typing.Any] = pydantic.Field(
        description="Key/value pairs for each input variable that the Test Suite expects."
    )
    evaluation_params: EvaluationParams = pydantic.Field(
        description="Parameters to use when evaluating the test case, specific to the test suite's evaluation metric."
    )

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().dict(**kwargs_with_defaults)

    class Config:
        frozen = True
        smart_union = True
        json_encoders = {dt.datetime: serialize_datetime}



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class VellumVariableType(str, enum.Enum):
    """
    * `STRING` - String
    * `JSON` - JSON
    * `CHAT_HISTORY` - Chat History
    * `SEARCH_RESULTS` - Search Results
    """

    STRING = "STRING"
    JSON = "JSON"
    CHAT_HISTORY = "CHAT_HISTORY"
    SEARCH_RESULTS = "SEARCH_RESULTS"

    def visit(
        self,
        string: typing.Callable[[], T_Result],
        json: typing.Callable[[], T_Result],
        chat_history: typing.Callable[[], T_Result],
        search_results: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is VellumVariableType.STRING:
            return string()
        if self is VellumVariableType.JSON:
            return json()
        if self is VellumVariableType.CHAT_HISTORY:
            return chat_history()
        if self is VellumVariableType.SEARCH_RESULTS:
            return search_results()



# This file was auto-generated by Fern from our API Definition.

import urllib.parse
from json.decoder import JSONDecodeError

import pydantic

from ...core.api_error import ApiError
from ...core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ...types.deployment_read import DeploymentRead


class DeploymentsClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def retrieve(self, id: str) -> DeploymentRead:
        """

        <strong style="background-color:#ffc107; color:white; padding:4px; border-radius:4px">Unstable</strong>

        Used to retrieve a deployment given its ID or name.

        Parameters:
            - id: str. Either the Deployment's ID or its unique name
        """
        _response = self._client_wrapper.httpx_client.request(
            "GET",
            urllib.parse.urljoin(f"{self._client_wrapper.get_environment().default}/", f"v1/deployments/{id}"),
            headers=self._client_wrapper.get_headers(),
            timeout=None,
        )
        if 200 <= _response.status_code < 300:
            return pydantic.parse_obj_as(DeploymentRead, _response.json())  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)


class AsyncDeploymentsClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def retrieve(self, id: str) -> DeploymentRead:
        """

        <strong style="background-color:#ffc107; color:white; padding:4px; border-radius:4px">Unstable</strong>

        Used to retrieve a deployment given its ID or name.

        Parameters:
            - id: str. Either the Deployment's ID or its unique name
        """
        _response = await self._client_wrapper.httpx_client.request(
            "GET",
            urllib.parse.urljoin(f"{self._client_wrapper.get_environment().default}/", f"v1/deployments/{id}"),
            headers=self._client_wrapper.get_headers(),
            timeout=None,
        )
        if 200 <= _response.status_code < 300:
            return pydantic.parse_obj_as(DeploymentRead, _response.json())  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)



# This file was auto-generated by Fern from our API Definition.

import typing
import urllib.parse
from json.decoder import JSONDecodeError

import pydantic

from ...core.api_error import ApiError
from ...core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ...core.jsonable_encoder import jsonable_encoder
from ...types.evaluation_params_request import EvaluationParamsRequest
from ...types.test_suite_test_case import TestSuiteTestCase

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class TestSuitesClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def upsert_test_suite_test_case(
        self,
        id: str,
        *,
        test_case_id: typing.Optional[str] = OMIT,
        label: typing.Optional[str] = OMIT,
        input_values: typing.Dict[str, typing.Any],
        evaluation_params: EvaluationParamsRequest,
    ) -> TestSuiteTestCase:
        """
        <strong style="background-color:#ffc107; color:white; padding:4px; border-radius:4px">Unstable</strong>

        Upserts a new test case for a test suite, keying off of the optionally provided test case id.

        If an id is provided and has a match, the test case will be updated. If no id is provided or no match
        is found, a new test case will be appended to the end.

        Note that a full replacement of the test case is performed, so any fields not provided will be removed
        or overwritten with default values.

        Parameters:
            - id: str. A UUID string identifying this test suite.

            - test_case_id: typing.Optional[str]. The id of the test case to update. If none is provided, an id will be generated and a new test case will be appended. <span style="white-space: nowrap">`non-empty`</span>

            - label: typing.Optional[str]. A human-friendly label for the test case.

            - input_values: typing.Dict[str, typing.Any]. Key/value pairs for each input variable that the Test Suite expects.

            - evaluation_params: EvaluationParamsRequest. Parameters to use when evaluating the test case, specific to the test suite's evaluation metric.
        """
        _request: typing.Dict[str, typing.Any] = {"input_values": input_values, "evaluation_params": evaluation_params}
        if test_case_id is not OMIT:
            _request["test_case_id"] = test_case_id
        if label is not OMIT:
            _request["label"] = label
        _response = self._client_wrapper.httpx_client.request(
            "POST",
            urllib.parse.urljoin(
                f"{self._client_wrapper.get_environment().default}/", f"v1/test-suites/{id}/test-cases"
            ),
            json=jsonable_encoder(_request),
            headers=self._client_wrapper.get_headers(),
            timeout=None,
        )
        if 200 <= _response.status_code < 300:
            return pydantic.parse_obj_as(TestSuiteTestCase, _response.json())  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def delete_test_suite_test_case(self, id: str, test_case_id: str) -> None:
        """
        <strong style="background-color:#ffc107; color:white; padding:4px; border-radius:4px">Unstable</strong>

        Deletes an existing test case for a test suite, keying off of the test case id.

        Parameters:
            - id: str. A UUID string identifying this test suite.

            - test_case_id: str. An id identifying the test case that you'd like to delete
        """
        _response = self._client_wrapper.httpx_client.request(
            "DELETE",
            urllib.parse.urljoin(
                f"{self._client_wrapper.get_environment().default}/", f"v1/test-suites/{id}/test-cases/{test_case_id}"
            ),
            headers=self._client_wrapper.get_headers(),
            timeout=None,
        )
        if 200 <= _response.status_code < 300:
            return
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)


class AsyncTestSuitesClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def upsert_test_suite_test_case(
        self,
        id: str,
        *,
        test_case_id: typing.Optional[str] = OMIT,
        label: typing.Optional[str] = OMIT,
        input_values: typing.Dict[str, typing.Any],
        evaluation_params: EvaluationParamsRequest,
    ) -> TestSuiteTestCase:
        """
        <strong style="background-color:#ffc107; color:white; padding:4px; border-radius:4px">Unstable</strong>

        Upserts a new test case for a test suite, keying off of the optionally provided test case id.

        If an id is provided and has a match, the test case will be updated. If no id is provided or no match
        is found, a new test case will be appended to the end.

        Note that a full replacement of the test case is performed, so any fields not provided will be removed
        or overwritten with default values.

        Parameters:
            - id: str. A UUID string identifying this test suite.

            - test_case_id: typing.Optional[str]. The id of the test case to update. If none is provided, an id will be generated and a new test case will be appended. <span style="white-space: nowrap">`non-empty`</span>

            - label: typing.Optional[str]. A human-friendly label for the test case.

            - input_values: typing.Dict[str, typing.Any]. Key/value pairs for each input variable that the Test Suite expects.

            - evaluation_params: EvaluationParamsRequest. Parameters to use when evaluating the test case, specific to the test suite's evaluation metric.
        """
        _request: typing.Dict[str, typing.Any] = {"input_values": input_values, "evaluation_params": evaluation_params}
        if test_case_id is not OMIT:
            _request["test_case_id"] = test_case_id
        if label is not OMIT:
            _request["label"] = label
        _response = await self._client_wrapper.httpx_client.request(
            "POST",
            urllib.parse.urljoin(
                f"{self._client_wrapper.get_environment().default}/", f"v1/test-suites/{id}/test-cases"
            ),
            json=jsonable_encoder(_request),
            headers=self._client_wrapper.get_headers(),
            timeout=None,
        )
        if 200 <= _response.status_code < 300:
            return pydantic.parse_obj_as(TestSuiteTestCase, _response.json())  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def delete_test_suite_test_case(self, id: str, test_case_id: str) -> None:
        """
        <strong style="background-color:#ffc107; color:white; padding:4px; border-radius:4px">Unstable</strong>

        Deletes an existing test case for a test suite, keying off of the test case id.

        Parameters:
            - id: str. A UUID string identifying this test suite.

            - test_case_id: str. An id identifying the test case that you'd like to delete
        """
        _response = await self._client_wrapper.httpx_client.request(
            "DELETE",
            urllib.parse.urljoin(
                f"{self._client_wrapper.get_environment().default}/", f"v1/test-suites/{id}/test-cases/{test_case_id}"
            ),
            headers=self._client_wrapper.get_headers(),
            timeout=None,
        )
        if 200 <= _response.status_code < 300:
            return
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class ProviderEnum(str, enum.Enum):
    """
    * `ANTHROPIC` - Anthropic
    * `COHERE` - Cohere
    * `GOOGLE` - Google
    * `HOSTED` - Hosted
    * `MOSAICML` - MosaicML
    * `MYSTIC` - Mystic
    * `OPENAI` - OpenAI
    * `PYQ` - Pyq
    """

    ANTHROPIC = "ANTHROPIC"
    COHERE = "COHERE"
    GOOGLE = "GOOGLE"
    HOSTED = "HOSTED"
    MOSAICML = "MOSAICML"
    MYSTIC = "MYSTIC"
    OPENAI = "OPENAI"
    PYQ = "PYQ"

    def visit(
        self,
        anthropic: typing.Callable[[], T_Result],
        cohere: typing.Callable[[], T_Result],
        google: typing.Callable[[], T_Result],
        hosted: typing.Callable[[], T_Result],
        mosaicml: typing.Callable[[], T_Result],
        mystic: typing.Callable[[], T_Result],
        openai: typing.Callable[[], T_Result],
        pyq: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is ProviderEnum.ANTHROPIC:
            return anthropic()
        if self is ProviderEnum.COHERE:
            return cohere()
        if self is ProviderEnum.GOOGLE:
            return google()
        if self is ProviderEnum.HOSTED:
            return hosted()
        if self is ProviderEnum.MOSAICML:
            return mosaicml()
        if self is ProviderEnum.MYSTIC:
            return mystic()
        if self is ProviderEnum.OPENAI:
            return openai()
        if self is ProviderEnum.PYQ:
            return pyq()



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic

from ..core.datetime_utils import serialize_datetime
from .metadata_filter_rule_combinator import MetadataFilterRuleCombinator
from .metadata_filter_rule_request import MetadataFilterRuleRequest


class MetadataFilterConfigRequest(pydantic.BaseModel):
    combinator: typing.Optional[MetadataFilterRuleCombinator]
    negated: typing.Optional[bool]
    rules: typing.Optional[typing.List[MetadataFilterRuleRequest]]
    field: typing.Optional[str] = pydantic.Field(description='<span style="white-space: nowrap">`non-empty`</span>')
    operator: typing.Optional[str] = pydantic.Field(description='<span style="white-space: nowrap">`non-empty`</span>')
    value: typing.Optional[str] = pydantic.Field(description='<span style="white-space: nowrap">`non-empty`</span>')

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().dict(**kwargs_with_defaults)

    class Config:
        frozen = True
        smart_union = True
        json_encoders = {dt.datetime: serialize_datetime}



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic

from ..core.datetime_utils import serialize_datetime
from .logprobs_enum import LogprobsEnum


class GenerateOptionsRequest(pydantic.BaseModel):
    logprobs: typing.Optional[LogprobsEnum] = pydantic.Field(
        description=(
            "Which logprobs to include, if any. Defaults to NONE.\n" "\n" "* `ALL` - ALL\n" "* `NONE` - NONE\n"
        )
    )

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().dict(**kwargs_with_defaults)

    class Config:
        frozen = True
        smart_union = True
        json_encoders = {dt.datetime: serialize_datetime}



# This file was auto-generated by Fern from our API Definition.

from .types import (
    BlockTypeEnum,
    ChatMessage,
    ChatMessageRequest,
    ChatMessageRole,
    ConditionalNodeResult,
    ConditionalNodeResultData,
    ContentType,
    DeploymentRead,
    DeploymentStatus,
    DocumentDocumentToDocumentIndex,
    DocumentIndexRead,
    DocumentIndexStatus,
    DocumentRead,
    DocumentStatus,
    EnrichedNormalizedCompletion,
    EnvironmentEnum,
    EvaluationParams,
    EvaluationParamsRequest,
    ExecuteWorkflowStreamErrorResponse,
    FinishReasonEnum,
    GenerateErrorResponse,
    GenerateOptionsRequest,
    GenerateRequest,
    GenerateResponse,
    GenerateResult,
    GenerateResultData,
    GenerateResultError,
    GenerateStreamResponse,
    GenerateStreamResult,
    GenerateStreamResultData,
    IndexingStateEnum,
    LogprobsEnum,
    MetadataFilterConfigRequest,
    MetadataFilterRuleCombinator,
    MetadataFilterRuleRequest,
    ModelTypeDeprecated,
    ModelVersionBuildConfig,
    ModelVersionCompilePromptResponse,
    ModelVersionCompiledPrompt,
    ModelVersionExecConfig,
    ModelVersionExecConfigParameters,
    ModelVersionRead,
    ModelVersionReadStatusEnum,
    ModelVersionSandboxSnapshot,
    NodeInputCompiledChatHistoryValue,
    NodeInputCompiledJsonValue,
    NodeInputCompiledSearchResultsValue,
    NodeInputCompiledStringValue,
    NodeInputVariableCompiledValue,
    NodeInputVariableCompiledValue_ChatHistory,
    NodeInputVariableCompiledValue_Json,
    NodeInputVariableCompiledValue_SearchResults,
    NodeInputVariableCompiledValue_String,
    NormalizedLogProbs,
    NormalizedTokenLogProbs,
    PaginatedSlimDocumentList,
    ProcessingFailureReasonEnum,
    ProcessingStateEnum,
    PromptNodeResult,
    PromptNodeResultData,
    PromptTemplateBlock,
    PromptTemplateBlockData,
    PromptTemplateBlockDataRequest,
    PromptTemplateBlockProperties,
    PromptTemplateBlockPropertiesRequest,
    PromptTemplateBlockRequest,
    ProviderEnum,
    RegisterPromptErrorResponse,
    RegisterPromptModelParametersRequest,
    RegisterPromptPrompt,
    RegisterPromptPromptInfoRequest,
    RegisterPromptResponse,
    RegisteredPromptDeployment,
    RegisteredPromptInputVariableRequest,
    RegisteredPromptModelVersion,
    RegisteredPromptSandbox,
    RegisteredPromptSandboxSnapshot,
    SandboxMetricInputParams,
    SandboxMetricInputParamsRequest,
    SandboxScenario,
    ScenarioInput,
    ScenarioInputRequest,
    ScenarioInputTypeEnum,
    SearchErrorResponse,
    SearchFiltersRequest,
    SearchNodeResult,
    SearchNodeResultData,
    SearchRequestOptionsRequest,
    SearchResponse,
    SearchResult,
    SearchResultDocument,
    SearchResultMergingRequest,
    SearchWeightsRequest,
    SlimDocument,
    SubmitCompletionActualRequest,
    SubmitCompletionActualsErrorResponse,
    SubmitWorkflowExecutionActualRequest,
    SubmitWorkflowExecutionActualRequest_ChatHistory,
    SubmitWorkflowExecutionActualRequest_Json,
    SubmitWorkflowExecutionActualRequest_String,
    TemplatingNodeChatHistoryResult,
    TemplatingNodeJsonResult,
    TemplatingNodeResult,
    TemplatingNodeResultData,
    TemplatingNodeResultOutput,
    TemplatingNodeResultOutput_ChatHistory,
    TemplatingNodeResultOutput_Json,
    TemplatingNodeResultOutput_SearchResults,
    TemplatingNodeResultOutput_String,
    TemplatingNodeSearchResultsResult,
    TemplatingNodeStringResult,
    TerminalNodeChatHistoryResult,
    TerminalNodeJsonResult,
    TerminalNodeResult,
    TerminalNodeResultData,
    TerminalNodeResultOutput,
    TerminalNodeResultOutput_ChatHistory,
    TerminalNodeResultOutput_Json,
    TerminalNodeResultOutput_SearchResults,
    TerminalNodeResultOutput_String,
    TerminalNodeSearchResultsResult,
    TerminalNodeStringResult,
    TestSuiteTestCase,
    UploadDocumentErrorResponse,
    UploadDocumentResponse,
    VellumVariable,
    VellumVariableType,
    WorkflowEventError,
    WorkflowExecutionActualChatHistoryRequest,
    WorkflowExecutionActualJsonRequest,
    WorkflowExecutionActualStringRequest,
    WorkflowExecutionEventErrorCode,
    WorkflowExecutionEventType,
    WorkflowExecutionNodeResultEvent,
    WorkflowExecutionWorkflowResultEvent,
    WorkflowNodeResultData,
    WorkflowNodeResultData_Conditional,
    WorkflowNodeResultData_Prompt,
    WorkflowNodeResultData_Search,
    WorkflowNodeResultData_Templating,
    WorkflowNodeResultData_Terminal,
    WorkflowNodeResultEvent,
    WorkflowNodeResultEventState,
    WorkflowRequestChatHistoryInputRequest,
    WorkflowRequestInputRequest,
    WorkflowRequestInputRequest_ChatHistory,
    WorkflowRequestInputRequest_Json,
    WorkflowRequestInputRequest_String,
    WorkflowRequestJsonInputRequest,
    WorkflowRequestStringInputRequest,
    WorkflowResultEvent,
    WorkflowResultEventOutputData,
    WorkflowResultEventOutputDataChatHistory,
    WorkflowResultEventOutputDataJson,
    WorkflowResultEventOutputDataSearchResults,
    WorkflowResultEventOutputDataString,
    WorkflowResultEventOutputData_ChatHistory,
    WorkflowResultEventOutputData_Json,
    WorkflowResultEventOutputData_SearchResults,
    WorkflowResultEventOutputData_String,
    WorkflowStreamEvent,
    WorkflowStreamEvent_Node,
    WorkflowStreamEvent_Workflow,
)
from .errors import BadRequestError, ConflictError, ForbiddenError, InternalServerError, NotFoundError
from .resources import (
    deployments,
    document_indexes,
    documents,
    model_versions,
    registered_prompts,
    sandboxes,
    test_suites,
)
from .environment import VellumEnvironment

__all__ = [
    "BadRequestError",
    "BlockTypeEnum",
    "ChatMessage",
    "ChatMessageRequest",
    "ChatMessageRole",
    "ConditionalNodeResult",
    "ConditionalNodeResultData",
    "ConflictError",
    "ContentType",
    "DeploymentRead",
    "DeploymentStatus",
    "DocumentDocumentToDocumentIndex",
    "DocumentIndexRead",
    "DocumentIndexStatus",
    "DocumentRead",
    "DocumentStatus",
    "EnrichedNormalizedCompletion",
    "EnvironmentEnum",
    "EvaluationParams",
    "EvaluationParamsRequest",
    "ExecuteWorkflowStreamErrorResponse",
    "FinishReasonEnum",
    "ForbiddenError",
    "GenerateErrorResponse",
    "GenerateOptionsRequest",
    "GenerateRequest",
    "GenerateResponse",
    "GenerateResult",
    "GenerateResultData",
    "GenerateResultError",
    "GenerateStreamResponse",
    "GenerateStreamResult",
    "GenerateStreamResultData",
    "IndexingStateEnum",
    "InternalServerError",
    "LogprobsEnum",
    "MetadataFilterConfigRequest",
    "MetadataFilterRuleCombinator",
    "MetadataFilterRuleRequest",
    "ModelTypeDeprecated",
    "ModelVersionBuildConfig",
    "ModelVersionCompilePromptResponse",
    "ModelVersionCompiledPrompt",
    "ModelVersionExecConfig",
    "ModelVersionExecConfigParameters",
    "ModelVersionRead",
    "ModelVersionReadStatusEnum",
    "ModelVersionSandboxSnapshot",
    "NodeInputCompiledChatHistoryValue",
    "NodeInputCompiledJsonValue",
    "NodeInputCompiledSearchResultsValue",
    "NodeInputCompiledStringValue",
    "NodeInputVariableCompiledValue",
    "NodeInputVariableCompiledValue_ChatHistory",
    "NodeInputVariableCompiledValue_Json",
    "NodeInputVariableCompiledValue_SearchResults",
    "NodeInputVariableCompiledValue_String",
    "NormalizedLogProbs",
    "NormalizedTokenLogProbs",
    "NotFoundError",
    "PaginatedSlimDocumentList",
    "ProcessingFailureReasonEnum",
    "ProcessingStateEnum",
    "PromptNodeResult",
    "PromptNodeResultData",
    "PromptTemplateBlock",
    "PromptTemplateBlockData",
    "PromptTemplateBlockDataRequest",
    "PromptTemplateBlockProperties",
    "PromptTemplateBlockPropertiesRequest",
    "PromptTemplateBlockRequest",
    "ProviderEnum",
    "RegisterPromptErrorResponse",
    "RegisterPromptModelParametersRequest",
    "RegisterPromptPrompt",
    "RegisterPromptPromptInfoRequest",
    "RegisterPromptResponse",
    "RegisteredPromptDeployment",
    "RegisteredPromptInputVariableRequest",
    "RegisteredPromptModelVersion",
    "RegisteredPromptSandbox",
    "RegisteredPromptSandboxSnapshot",
    "SandboxMetricInputParams",
    "SandboxMetricInputParamsRequest",
    "SandboxScenario",
    "ScenarioInput",
    "ScenarioInputRequest",
    "ScenarioInputTypeEnum",
    "SearchErrorResponse",
    "SearchFiltersRequest",
    "SearchNodeResult",
    "SearchNodeResultData",
    "SearchRequestOptionsRequest",
    "SearchResponse",
    "SearchResult",
    "SearchResultDocument",
    "SearchResultMergingRequest",
    "SearchWeightsRequest",
    "SlimDocument",
    "SubmitCompletionActualRequest",
    "SubmitCompletionActualsErrorResponse",
    "SubmitWorkflowExecutionActualRequest",
    "SubmitWorkflowExecutionActualRequest_ChatHistory",
    "SubmitWorkflowExecutionActualRequest_Json",
    "SubmitWorkflowExecutionActualRequest_String",
    "TemplatingNodeChatHistoryResult",
    "TemplatingNodeJsonResult",
    "TemplatingNodeResult",
    "TemplatingNodeResultData",
    "TemplatingNodeResultOutput",
    "TemplatingNodeResultOutput_ChatHistory",
    "TemplatingNodeResultOutput_Json",
    "TemplatingNodeResultOutput_SearchResults",
    "TemplatingNodeResultOutput_String",
    "TemplatingNodeSearchResultsResult",
    "TemplatingNodeStringResult",
    "TerminalNodeChatHistoryResult",
    "TerminalNodeJsonResult",
    "TerminalNodeResult",
    "TerminalNodeResultData",
    "TerminalNodeResultOutput",
    "TerminalNodeResultOutput_ChatHistory",
    "TerminalNodeResultOutput_Json",
    "TerminalNodeResultOutput_SearchResults",
    "TerminalNodeResultOutput_String",
    "TerminalNodeSearchResultsResult",
    "TerminalNodeStringResult",
    "TestSuiteTestCase",
    "UploadDocumentErrorResponse",
    "UploadDocumentResponse",
    "VellumEnvironment",
    "VellumVariable",
    "VellumVariableType",
    "WorkflowEventError",
    "WorkflowExecutionActualChatHistoryRequest",
    "WorkflowExecutionActualJsonRequest",
    "WorkflowExecutionActualStringRequest",
    "WorkflowExecutionEventErrorCode",
    "WorkflowExecutionEventType",
    "WorkflowExecutionNodeResultEvent",
    "WorkflowExecutionWorkflowResultEvent",
    "WorkflowNodeResultData",
    "WorkflowNodeResultData_Conditional",
    "WorkflowNodeResultData_Prompt",
    "WorkflowNodeResultData_Search",
    "WorkflowNodeResultData_Templating",
    "WorkflowNodeResultData_Terminal",
    "WorkflowNodeResultEvent",
    "WorkflowNodeResultEventState",
    "WorkflowRequestChatHistoryInputRequest",
    "WorkflowRequestInputRequest",
    "WorkflowRequestInputRequest_ChatHistory",
    "WorkflowRequestInputRequest_Json",
    "WorkflowRequestInputRequest_String",
    "WorkflowRequestJsonInputRequest",
    "WorkflowRequestStringInputRequest",
    "WorkflowResultEvent",
    "WorkflowResultEventOutputData",
    "WorkflowResultEventOutputDataChatHistory",
    "WorkflowResultEventOutputDataJson",
    "WorkflowResultEventOutputDataSearchResults",
    "WorkflowResultEventOutputDataString",
    "WorkflowResultEventOutputData_ChatHistory",
    "WorkflowResultEventOutputData_Json",
    "WorkflowResultEventOutputData_SearchResults",
    "WorkflowResultEventOutputData_String",
    "WorkflowStreamEvent",
    "WorkflowStreamEvent_Node",
    "WorkflowStreamEvent_Workflow",
    "deployments",
    "document_indexes",
    "documents",
    "model_versions",
    "registered_prompts",
    "sandboxes",
    "test_suites",
]



# This file was auto-generated by Fern from our API Definition.

from .block_type_enum import BlockTypeEnum
from .chat_message import ChatMessage
from .chat_message_request import ChatMessageRequest
from .chat_message_role import ChatMessageRole
from .conditional_node_result import ConditionalNodeResult
from .conditional_node_result_data import ConditionalNodeResultData
from .content_type import ContentType
from .deployment_read import DeploymentRead
from .deployment_status import DeploymentStatus
from .document_document_to_document_index import DocumentDocumentToDocumentIndex
from .document_index_read import DocumentIndexRead
from .document_index_status import DocumentIndexStatus
from .document_read import DocumentRead
from .document_status import DocumentStatus
from .enriched_normalized_completion import EnrichedNormalizedCompletion
from .environment_enum import EnvironmentEnum
from .evaluation_params import EvaluationParams
from .evaluation_params_request import EvaluationParamsRequest
from .execute_workflow_stream_error_response import ExecuteWorkflowStreamErrorResponse
from .finish_reason_enum import FinishReasonEnum
from .generate_error_response import GenerateErrorResponse
from .generate_options_request import GenerateOptionsRequest
from .generate_request import GenerateRequest
from .generate_response import GenerateResponse
from .generate_result import GenerateResult
from .generate_result_data import GenerateResultData
from .generate_result_error import GenerateResultError
from .generate_stream_response import GenerateStreamResponse
from .generate_stream_result import GenerateStreamResult
from .generate_stream_result_data import GenerateStreamResultData
from .indexing_state_enum import IndexingStateEnum
from .logprobs_enum import LogprobsEnum
from .metadata_filter_config_request import MetadataFilterConfigRequest
from .metadata_filter_rule_combinator import MetadataFilterRuleCombinator
from .metadata_filter_rule_request import MetadataFilterRuleRequest
from .model_type_deprecated import ModelTypeDeprecated
from .model_version_build_config import ModelVersionBuildConfig
from .model_version_compile_prompt_response import ModelVersionCompilePromptResponse
from .model_version_compiled_prompt import ModelVersionCompiledPrompt
from .model_version_exec_config import ModelVersionExecConfig
from .model_version_exec_config_parameters import ModelVersionExecConfigParameters
from .model_version_read import ModelVersionRead
from .model_version_read_status_enum import ModelVersionReadStatusEnum
from .model_version_sandbox_snapshot import ModelVersionSandboxSnapshot
from .node_input_compiled_chat_history_value import NodeInputCompiledChatHistoryValue
from .node_input_compiled_json_value import NodeInputCompiledJsonValue
from .node_input_compiled_search_results_value import NodeInputCompiledSearchResultsValue
from .node_input_compiled_string_value import NodeInputCompiledStringValue
from .node_input_variable_compiled_value import (
    NodeInputVariableCompiledValue,
    NodeInputVariableCompiledValue_ChatHistory,
    NodeInputVariableCompiledValue_Json,
    NodeInputVariableCompiledValue_SearchResults,
    NodeInputVariableCompiledValue_String,
)
from .normalized_log_probs import NormalizedLogProbs
from .normalized_token_log_probs import NormalizedTokenLogProbs
from .paginated_slim_document_list import PaginatedSlimDocumentList
from .processing_failure_reason_enum import ProcessingFailureReasonEnum
from .processing_state_enum import ProcessingStateEnum
from .prompt_node_result import PromptNodeResult
from .prompt_node_result_data import PromptNodeResultData
from .prompt_template_block import PromptTemplateBlock
from .prompt_template_block_data import PromptTemplateBlockData
from .prompt_template_block_data_request import PromptTemplateBlockDataRequest
from .prompt_template_block_properties import PromptTemplateBlockProperties
from .prompt_template_block_properties_request import PromptTemplateBlockPropertiesRequest
from .prompt_template_block_request import PromptTemplateBlockRequest
from .provider_enum import ProviderEnum
from .register_prompt_error_response import RegisterPromptErrorResponse
from .register_prompt_model_parameters_request import RegisterPromptModelParametersRequest
from .register_prompt_prompt import RegisterPromptPrompt
from .register_prompt_prompt_info_request import RegisterPromptPromptInfoRequest
from .register_prompt_response import RegisterPromptResponse
from .registered_prompt_deployment import RegisteredPromptDeployment
from .registered_prompt_input_variable_request import RegisteredPromptInputVariableRequest
from .registered_prompt_model_version import RegisteredPromptModelVersion
from .registered_prompt_sandbox import RegisteredPromptSandbox
from .registered_prompt_sandbox_snapshot import RegisteredPromptSandboxSnapshot
from .sandbox_metric_input_params import SandboxMetricInputParams
from .sandbox_metric_input_params_request import SandboxMetricInputParamsRequest
from .sandbox_scenario import SandboxScenario
from .scenario_input import ScenarioInput
from .scenario_input_request import ScenarioInputRequest
from .scenario_input_type_enum import ScenarioInputTypeEnum
from .search_error_response import SearchErrorResponse
from .search_filters_request import SearchFiltersRequest
from .search_node_result import SearchNodeResult
from .search_node_result_data import SearchNodeResultData
from .search_request_options_request import SearchRequestOptionsRequest
from .search_response import SearchResponse
from .search_result import SearchResult
from .search_result_document import SearchResultDocument
from .search_result_merging_request import SearchResultMergingRequest
from .search_weights_request import SearchWeightsRequest
from .slim_document import SlimDocument
from .submit_completion_actual_request import SubmitCompletionActualRequest
from .submit_completion_actuals_error_response import SubmitCompletionActualsErrorResponse
from .submit_workflow_execution_actual_request import (
    SubmitWorkflowExecutionActualRequest,
    SubmitWorkflowExecutionActualRequest_ChatHistory,
    SubmitWorkflowExecutionActualRequest_Json,
    SubmitWorkflowExecutionActualRequest_String,
)
from .templating_node_chat_history_result import TemplatingNodeChatHistoryResult
from .templating_node_json_result import TemplatingNodeJsonResult
from .templating_node_result import TemplatingNodeResult
from .templating_node_result_data import TemplatingNodeResultData
from .templating_node_result_output import (
    TemplatingNodeResultOutput,
    TemplatingNodeResultOutput_ChatHistory,
    TemplatingNodeResultOutput_Json,
    TemplatingNodeResultOutput_SearchResults,
    TemplatingNodeResultOutput_String,
)
from .templating_node_search_results_result import TemplatingNodeSearchResultsResult
from .templating_node_string_result import TemplatingNodeStringResult
from .terminal_node_chat_history_result import TerminalNodeChatHistoryResult
from .terminal_node_json_result import TerminalNodeJsonResult
from .terminal_node_result import TerminalNodeResult
from .terminal_node_result_data import TerminalNodeResultData
from .terminal_node_result_output import (
    TerminalNodeResultOutput,
    TerminalNodeResultOutput_ChatHistory,
    TerminalNodeResultOutput_Json,
    TerminalNodeResultOutput_SearchResults,
    TerminalNodeResultOutput_String,
)
from .terminal_node_search_results_result import TerminalNodeSearchResultsResult
from .terminal_node_string_result import TerminalNodeStringResult
from .test_suite_test_case import TestSuiteTestCase
from .upload_document_error_response import UploadDocumentErrorResponse
from .upload_document_response import UploadDocumentResponse
from .vellum_variable import VellumVariable
from .vellum_variable_type import VellumVariableType
from .workflow_event_error import WorkflowEventError
from .workflow_execution_actual_chat_history_request import WorkflowExecutionActualChatHistoryRequest
from .workflow_execution_actual_json_request import WorkflowExecutionActualJsonRequest
from .workflow_execution_actual_string_request import WorkflowExecutionActualStringRequest
from .workflow_execution_event_error_code import WorkflowExecutionEventErrorCode
from .workflow_execution_event_type import WorkflowExecutionEventType
from .workflow_execution_node_result_event import WorkflowExecutionNodeResultEvent
from .workflow_execution_workflow_result_event import WorkflowExecutionWorkflowResultEvent
from .workflow_node_result_data import (
    WorkflowNodeResultData,
    WorkflowNodeResultData_Conditional,
    WorkflowNodeResultData_Prompt,
    WorkflowNodeResultData_Search,
    WorkflowNodeResultData_Templating,
    WorkflowNodeResultData_Terminal,
)
from .workflow_node_result_event import WorkflowNodeResultEvent
from .workflow_node_result_event_state import WorkflowNodeResultEventState
from .workflow_request_chat_history_input_request import WorkflowRequestChatHistoryInputRequest
from .workflow_request_input_request import (
    WorkflowRequestInputRequest,
    WorkflowRequestInputRequest_ChatHistory,
    WorkflowRequestInputRequest_Json,
    WorkflowRequestInputRequest_String,
)
from .workflow_request_json_input_request import WorkflowRequestJsonInputRequest
from .workflow_request_string_input_request import WorkflowRequestStringInputRequest
from .workflow_result_event import WorkflowResultEvent
from .workflow_result_event_output_data import (
    WorkflowResultEventOutputData,
    WorkflowResultEventOutputData_ChatHistory,
    WorkflowResultEventOutputData_Json,
    WorkflowResultEventOutputData_SearchResults,
    WorkflowResultEventOutputData_String,
)
from .workflow_result_event_output_data_chat_history import WorkflowResultEventOutputDataChatHistory
from .workflow_result_event_output_data_json import WorkflowResultEventOutputDataJson
from .workflow_result_event_output_data_search_results import WorkflowResultEventOutputDataSearchResults
from .workflow_result_event_output_data_string import WorkflowResultEventOutputDataString
from .workflow_stream_event import WorkflowStreamEvent, WorkflowStreamEvent_Node, WorkflowStreamEvent_Workflow

__all__ = [
    "BlockTypeEnum",
    "ChatMessage",
    "ChatMessageRequest",
    "ChatMessageRole",
    "ConditionalNodeResult",
    "ConditionalNodeResultData",
    "ContentType",
    "DeploymentRead",
    "DeploymentStatus",
    "DocumentDocumentToDocumentIndex",
    "DocumentIndexRead",
    "DocumentIndexStatus",
    "DocumentRead",
    "DocumentStatus",
    "EnrichedNormalizedCompletion",
    "EnvironmentEnum",
    "EvaluationParams",
    "EvaluationParamsRequest",
    "ExecuteWorkflowStreamErrorResponse",
    "FinishReasonEnum",
    "GenerateErrorResponse",
    "GenerateOptionsRequest",
    "GenerateRequest",
    "GenerateResponse",
    "GenerateResult",
    "GenerateResultData",
    "GenerateResultError",
    "GenerateStreamResponse",
    "GenerateStreamResult",
    "GenerateStreamResultData",
    "IndexingStateEnum",
    "LogprobsEnum",
    "MetadataFilterConfigRequest",
    "MetadataFilterRuleCombinator",
    "MetadataFilterRuleRequest",
    "ModelTypeDeprecated",
    "ModelVersionBuildConfig",
    "ModelVersionCompilePromptResponse",
    "ModelVersionCompiledPrompt",
    "ModelVersionExecConfig",
    "ModelVersionExecConfigParameters",
    "ModelVersionRead",
    "ModelVersionReadStatusEnum",
    "ModelVersionSandboxSnapshot",
    "NodeInputCompiledChatHistoryValue",
    "NodeInputCompiledJsonValue",
    "NodeInputCompiledSearchResultsValue",
    "NodeInputCompiledStringValue",
    "NodeInputVariableCompiledValue",
    "NodeInputVariableCompiledValue_ChatHistory",
    "NodeInputVariableCompiledValue_Json",
    "NodeInputVariableCompiledValue_SearchResults",
    "NodeInputVariableCompiledValue_String",
    "NormalizedLogProbs",
    "NormalizedTokenLogProbs",
    "PaginatedSlimDocumentList",
    "ProcessingFailureReasonEnum",
    "ProcessingStateEnum",
    "PromptNodeResult",
    "PromptNodeResultData",
    "PromptTemplateBlock",
    "PromptTemplateBlockData",
    "PromptTemplateBlockDataRequest",
    "PromptTemplateBlockProperties",
    "PromptTemplateBlockPropertiesRequest",
    "PromptTemplateBlockRequest",
    "ProviderEnum",
    "RegisterPromptErrorResponse",
    "RegisterPromptModelParametersRequest",
    "RegisterPromptPrompt",
    "RegisterPromptPromptInfoRequest",
    "RegisterPromptResponse",
    "RegisteredPromptDeployment",
    "RegisteredPromptInputVariableRequest",
    "RegisteredPromptModelVersion",
    "RegisteredPromptSandbox",
    "RegisteredPromptSandboxSnapshot",
    "SandboxMetricInputParams",
    "SandboxMetricInputParamsRequest",
    "SandboxScenario",
    "ScenarioInput",
    "ScenarioInputRequest",
    "ScenarioInputTypeEnum",
    "SearchErrorResponse",
    "SearchFiltersRequest",
    "SearchNodeResult",
    "SearchNodeResultData",
    "SearchRequestOptionsRequest",
    "SearchResponse",
    "SearchResult",
    "SearchResultDocument",
    "SearchResultMergingRequest",
    "SearchWeightsRequest",
    "SlimDocument",
    "SubmitCompletionActualRequest",
    "SubmitCompletionActualsErrorResponse",
    "SubmitWorkflowExecutionActualRequest",
    "SubmitWorkflowExecutionActualRequest_ChatHistory",
    "SubmitWorkflowExecutionActualRequest_Json",
    "SubmitWorkflowExecutionActualRequest_String",
    "TemplatingNodeChatHistoryResult",
    "TemplatingNodeJsonResult",
    "TemplatingNodeResult",
    "TemplatingNodeResultData",
    "TemplatingNodeResultOutput",
    "TemplatingNodeResultOutput_ChatHistory",
    "TemplatingNodeResultOutput_Json",
    "TemplatingNodeResultOutput_SearchResults",
    "TemplatingNodeResultOutput_String",
    "TemplatingNodeSearchResultsResult",
    "TemplatingNodeStringResult",
    "TerminalNodeChatHistoryResult",
    "TerminalNodeJsonResult",
    "TerminalNodeResult",
    "TerminalNodeResultData",
    "TerminalNodeResultOutput",
    "TerminalNodeResultOutput_ChatHistory",
    "TerminalNodeResultOutput_Json",
    "TerminalNodeResultOutput_SearchResults",
    "TerminalNodeResultOutput_String",
    "TerminalNodeSearchResultsResult",
    "TerminalNodeStringResult",
    "TestSuiteTestCase",
    "UploadDocumentErrorResponse",
    "UploadDocumentResponse",
    "VellumVariable",
    "VellumVariableType",
    "WorkflowEventError",
    "WorkflowExecutionActualChatHistoryRequest",
    "WorkflowExecutionActualJsonRequest",
    "WorkflowExecutionActualStringRequest",
    "WorkflowExecutionEventErrorCode",
    "WorkflowExecutionEventType",
    "WorkflowExecutionNodeResultEvent",
    "WorkflowExecutionWorkflowResultEvent",
    "WorkflowNodeResultData",
    "WorkflowNodeResultData_Conditional",
    "WorkflowNodeResultData_Prompt",
    "WorkflowNodeResultData_Search",
    "WorkflowNodeResultData_Templating",
    "WorkflowNodeResultData_Terminal",
    "WorkflowNodeResultEvent",
    "WorkflowNodeResultEventState",
    "WorkflowRequestChatHistoryInputRequest",
    "WorkflowRequestInputRequest",
    "WorkflowRequestInputRequest_ChatHistory",
    "WorkflowRequestInputRequest_Json",
    "WorkflowRequestInputRequest_String",
    "WorkflowRequestJsonInputRequest",
    "WorkflowRequestStringInputRequest",
    "WorkflowResultEvent",
    "WorkflowResultEventOutputData",
    "WorkflowResultEventOutputDataChatHistory",
    "WorkflowResultEventOutputDataJson",
    "WorkflowResultEventOutputDataSearchResults",
    "WorkflowResultEventOutputDataString",
    "WorkflowResultEventOutputData_ChatHistory",
    "WorkflowResultEventOutputData_Json",
    "WorkflowResultEventOutputData_SearchResults",
    "WorkflowResultEventOutputData_String",
    "WorkflowStreamEvent",
    "WorkflowStreamEvent_Node",
    "WorkflowStreamEvent_Workflow",
]
